@@ -1,5 +1,5 @@
 /* libmpdclient
-   (c) 2003-2010 The Music Player Daemon Project
+   (c) 2003-2018 The Music Player Daemon Project
    This project's homepage is: http://www.musicpd.org
 
    Redistribution and use in source and binary forms, with or without
@@ -39,9 +39,10 @@
 #ifndef MPD_DIRECTORY_H
 #define MPD_DIRECTORY_H
 
-#include <mpd/compiler.h>
+#include "compiler.h"
 
 #include <stdbool.h>
+#include <time.h>
 
 struct mpd_pair;
 struct mpd_connection;
@@ -80,6 +81,16 @@ mpd_pure
 const char *
 mpd_directory_get_path(const struct mpd_directory *directory);
 
+/**
+ * @return the POSIX UTC time stamp of the last modification, or 0 if
+ * that is unknown
+ *
+ * @since libmpdclient 2.9
+ */
+mpd_pure
+time_t
+mpd_directory_get_last_modified(const struct mpd_directory *directory);
+
 /**
  * Begins parsing a new directory.
  *
